@@ -143,8 +143,10 @@ sub dispatch {
 	}
 	my $dispatch;
 	my $path = $t->request->uri->path;
+	my $caps = scalar @{ $t->captured || [] };
 	DISPATCH: for my $candidate (reverse @{$dispatcher}) {
 		next DISPATCH unless ($candidate->{lc($t->request->method)} || $candidate->{any});
+		next DISPATCH unless (!$candidate->{captured} || $caps == $candidate->{captured});
 		if ($candidate->{params}) {
 			for my $param (keys %{$candidate->{params}}) {
 				next DISPATCH if (!$t->params->{$param});
@@ -197,7 +199,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.104
+Version 0.105
 
 =cut
 
@@ -235,7 +237,7 @@ Version 0.104
 		... # 4
 	}
 
-	sub other :get :path(foo/bar) {
+	sub other :get :path(foo/(.*)/bar) :captured(1) {
 		... # 5
 	}
 
@@ -266,7 +268,7 @@ Version 0.104
 	GET http://localhost:5000/?req=purchase&virtual=1 #2
 	POST http://localhost:5000/ {"req":"purchase", "virtual":1} #4
 
-	GET http://localhost:5000/foo/bar #5
+	GET http://localhost:5000/foo/555/bar #5
 
 =cut
 
